// drop "Apple Color Emoji" from Bootstrap's native font stack, otherwise the OK and ×; icon are rendered in black.
$font-family-sans-serif: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif, "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";

@import "bootstrap/scss/functions";
@import "bootstrap/scss/variables";

// configure the font include pathes
$fa-font-path: unquote(get-setting(NODE_MODULES_URL) + "font-awesome/fonts");

// navbar
$navbar-extra-top-height: 50px;

// table-like item-lists
$shop-item-hover-bg: $gray-100 !important;
$shop-border-color: $gray-300 !important;
