[ng-cloak], .ng-cloak {
	display: none !important;
}

.animate-show {
	opacity: 1;
	&.ng-hide-add.ng-hide-add-active, &.ng-hide-remove.ng-hide-remove-active {
		-webkit-transition: all linear 0.25s;
		transition: all linear 0.25s;
	}
	&.ng-hide {
		opacity: 0;
		-webkit-transition: all linear 0.25s;
		transition: all linear 0.25s;
	}
}
