{% load static sekizai_tags sass_tags %}{% spaceless %}

{% block extra-styles %}{% endblock %}

{% block extra-scripts %}
	{% addtoblock "js" %}<script src="{% static 'shop/js/digest.js' %}" type="text/javascript"></script>{% endaddtoblock %}
	{% add_data "ng-requires" "django.shop.digest" %}
	{% addtoblock "ng-config" %}['checkoutDigestProvider', function(provider) { provider.setEndpoint("{% url 'shop:checkout-digest' %}"); }]{% endaddtoblock %}
{% endblock %}

{% block summary_tag %}{% verbatim %}
<div class="alert alert-danger">Please extend template <code>shop/checkout/digest-base.html</code> and override <code>{% block summary_tag %}</code></div>
{% endverbatim %}{% endblock %}

{% endspaceless %}
