{# Fallback template if none is found in "myshop/products/search-<product_model>-media.html" #}
{# It is used to render the figure in each line of possible search results #}
<div class="media">
	<a href="{{ product.get_absolute_url }}">
{% block sample-image %}
		<img width="80" height="80" class="mr-3" src="{% include './sample-image.svg' %}" />
{% endblock %}
	</a>
	<div class="media-body">
		<h5 class="mt-0"><a href="{{ product.get_absolute_url }}">{{ product.product_name }}</a></h5>
		{{ product.caption|truncatewords_html:30 }}
	</div>
</div>
