{% extends "./anonymous-base.html" %}
{% load i18n %}

{% block form-title %}{% trans "Please enter your new password twice" %}{% endblock %}

{% block form-content %}
	{% if data.validlink %}
<form name="{{ form_name }}" djng-endpoint="{{ request.path }}" role="form" novalidate>
	{% include "./form-messages.html" %}
	{% include "./change-password-fields.html" %}
</form>
	{% else %}
<div class="alert alert-danger" role="alert">
	{% trans "The password reset link was invalid, possibly because it has already been used." %}
</div>
	{% endif %}
{% endblock form-content %}
