{% load i18n %}

{% include "shop/djng-form.html" %}

{% if customer.is_authenticated %}
<div class="card">
	<div class="card-header">
	{% block form-title %}Panel Title{% endblock %}
	</div>

	<div class="card-body">
	{% block form-content %}{% endblock %}
	</div>
</div>
{% else %}
<div class="alert alert-danger" role="alert">{% trans "This form shall only be reachable by authenticated users" %}</div>
{% endif %}
