
figure.figure {
	border-width: $border-width;
	border-color: $border-color;
	border-style: solid;
	border-radius: $border-radius;
	padding: $spacer $spacer 0;
	width: 100%;
	height: 100%;
	display: flex;
	flex-direction: column;
	justify-content: space-between;
	a, a:hover, a:active {
		color: $body-color;
		text-decoration: none;
	}
}
