{% extends "shop/checkout/digest-base.html" %}

{% block summary_tag %}
<div class="form-group">
	{% if headline_legend %}
	<h5>{{ billing_address_form.legend }}</h5>
	{% endif %}
	<shop-checkout-digest initial-tag="{billing_address_tag: '{{ billing_address_form.as_text }}'}">
		<pre ng-bind="checkoutDigest.billing_address_tag" class="shop-checkout-summary"></pre>
	</shop-checkout-digest>
</div>
{% endblock %}
