{% load static sass_tags sekizai_tags %}{% spaceless %}

{% if stylesheet_url %}{% addtoblock "css" %}<link href="{{ stylesheet_url }}" rel="stylesheet" type="text/css" />{% endaddtoblock %}{% endif %}
{% include "shop/djng-form.html" %}

{% with instance_css_classes=instance.css_classes instance_inline_styles=instance.inline_styles disable_invalid=instance.glossary.disable_invalid|default:True %}
	<button ng-click="{% block ng-click %}do(prepare()).then(update()).then(showOK()).then(delay(333)).then(redirectTo('{{ instance.link }}')).catch(showFail()).then(delay(1500)).finally(restore()){% endblock %}"{% if disable_invalid %} ng-disabled="isDisabled()"{% endif %}{% if instance_css_classes %} class="{{ instance_css_classes }}"{% endif %}{% if instance_inline_styles %} style="{{ instance_inline_styles }}"{% endif %}>
		{{ icon_left }}{{ instance.content }}{{ icon_right }}
	</button>
{% endwith %}

{% endspaceless %}
