{# Fallback template if none is found in "myshop/products/watch-<product_model>-media.html" #}
{# It is used to render the figure in each line item when rendering the watch-list #}
{% extends "shop/products/cart-product-media.html" %}
