{% load i18n %}{% spaceless %}

{% include "./form-messages.html" %}
<div class="form-group has-feedback">
	<label for="email">{% trans "Your e-mail address" %}</label>
	<div class="input-group" ng-class="hasError('email')">
		<div class="input-group-prepend"><i class="input-group-text fa fa-envelope-o"></i></div>
		<input type="email" class="form-control" name="email" ng-model="form_data.email" value="" placeholder="{% trans 'Email' %}" ng-required="true" />
	</div>
	<ul ng-show="{{ form_name }}.email.$dirty && {{ form_name }}.email.$touched" class="djng-field-errors" ng-cloak>
		<li ng-show="{{ form_name }}.email.$error.required" class="invalid">{% trans "This field is required." %}</li>
		<li ng-show="{{ form_name }}.email.$error.email" class="invalid">{% trans "Enter a valid email address." %}</li>
		<li ng-show="{{ form_name }}.email.$valid" class="valid"></li>
	</ul>
	<ul ng-show="{{ form_name }}.email.$pristine" class="djng-form-control-feedback djng-field-errors" ng-cloak>
		<li ng-show="{{ form_name }}.email.$error.rejected" class="invalid" ng-bind="{{ form_name }}.email.$message"></li>
	</ul>
</div>

{#% page_url 'shop-login' as login_url %#}

<div class="form-group">
	<button class="btn btn-warning" type="button" ng-click="{% include "./proceed-with.html" with proceed_delay=5000 %}" ng-disabled="isDisabled()">
		{% trans "Reset Password" %}
		<i class="fa fa-recycle"></i>
	</button>
</div>
{% endspaceless %}
