{% load i18n %}{% spaceless %}
<div class="form-group has-feedback">
	<label for="new_password1">{% trans "New Password" %}</label>
	<div class="input-group">
		<div class="input-group-prepend"><i class="input-group-text fa fa-key"></i></div>
		<input type="password" class="form-control" name="new_password1" ng-model="form_data.new_password1" placeholder="{% trans 'New Password' %}" ng-required="true" />
	</div>
	<ul ng-show="{{ form_name }}.new_password1.$touched" class="djng-form-control-feedback djng-field-errors" ng-cloak>
		<li ng-show="{{ form_name }}.new_password1.$error.required" class="invalid">{% trans "This field is required." %}</li>
		<li ng-show="{{ form_name }}.new_password1.$valid" class="valid"></li>
	</ul>
	<ul ng-show="{{ form_name }}.new_password1.$error.rejected && {{ form_name }}.new_password1.$pristine" class="shop-form-error" ng-cloak>
		<li ng-bind="{{ form_name }}.new_password1.$message"></li>
	</ul>
</div>

<div class="form-group has-feedback">
	<label for="new_password2">{% trans "Confirm Password" %}</label>
	<div class="input-group">
		<div class="input-group-prepend"><i class="input-group-text fa fa-key"></i></div>
		<input type="password" class="form-control" name="new_password2" ng-model="form_data.new_password2" placeholder="{% trans 'Confirm Password' %}" ng-required="true" />
	</div>
	<ul ng-show="{{ form_name }}.new_password2.$touched" class="djng-form-control-feedback djng-field-errors" ng-cloak>
		<li ng-show="{{ form_name }}.new_password2.$error.required" class="invalid">{% trans "This field is required." %}</li>
		<li ng-show="{{ form_name }}.new_password2.$valid" class="valid"></li>
	</ul>
	<ul ng-show="{{ form_name }}.new_password2.$error.rejected && {{ form_name }}.new_password2.$pristine" class="shop-form-error" ng-cloak>
		<li class="invalid" ng-bind="{{ form_name }}.new_password2.$message"></li>
	</ul>
</div>

<div class="form-group">
	<button type="button" ng-disabled="isDisabled()" ng-click="{% include "./proceed-with.html" with proceed_delay=3500 %}" class="btn btn-primary">
		{% trans 'Change Password' %}
		<i class="fa fa-save" aria-hidden="true"></i>
	</button>
</div>
{% endspaceless %}
