{% load cms_tags i18n %}
{% page_url "shop-watch-list" as shop_watch_list_url %}
{% if shop_watch_list_url %}
	{% page_attribute "menu_title" "shop-watch-list" as tooltip %}
{% else %}
	{% url "shop-watch-list" as shop_watch_list_url %}
	{% trans "Watch List" as tooltip %}
{% endif %}
{% if shop_watch_list_url %}
<li class="nav-item {{ item_class }}">
	<a class="nav-link" href="{{ shop_watch_list_url }}" title="{{ tooltip }}"><i class="fa fa-heart" uib-tooltip="{{ tooltip }}" tooltip-placement="left"></i></a>
</li>
{% endif %}
