{% extends "shop/checkout/dialog-base.html" %}
{% load sekizai_tags %}

{% block extra-styles %}
	{{ block.super }}
	{% for stylesheet in customer_form.media.render_css %}{% addtoblock "css" %}{{ stylesheet }}{% endaddtoblock %}{% endfor %}
{% endblock %}

{% block dialog_form %}
<form name="{{ customer_form.form_name }}" novalidate>
	<fieldset>
	{% if headline_legend %}
		<legend>{{ customer_form.legend }}</legend>
	{% endif %}
		{{ customer_form.as_div }}
	</fieldset>
</form>
{% endblock %}
