{% extends "./login.html" %}
{% load i18n %}

{% block form-content %}{{ block.super }}{% spaceless %}
<div style="margin-top: -3rem; margin-bottom: 4rem;">
	<a ng-click="showResetForm=!showResetForm;" class="btn btn-link pull-right">{% trans "Password Forgotten?" %}</a>
</div>
	{% with form_name='password_reset_request_form' %}
<form name="{{ form_name }}" djng-endpoint="{% url 'shop:password-reset-request' %}" ng-show="showResetForm" ng-cloak role="form" novalidate>
		{% include "./password-reset-request-fields.html" %}
</form>
	{% endwith %}
{% endspaceless %}{% endblock form-content %}
