<bsp-scrollpanel>
	<ul>{% for product in products %}
		<li>{% include "shop/catalog/product-figure.html" %}</li>
	{% endfor %}</ul>
</bsp-scrollpanel>

{% include "shop/catalog/bsp-scrollpanel.tmpl.html" %}
