@import "variables";

.shop-list-item {
	border-color: $shop-border-color;
	&:hover {
		background-color: $shop-item-hover-bg;
	}
	.form-inline {
		div:first-child, div:last-child {
			width: 7.5rem;
			text-align: right;
		}
		input {
			width: 4rem;
		}
	}
	.shop-item-control {
		width: 7.5rem;
	}
	.badge {
		white-space: normal;
	}
}

.shop-double-border {
	border-top-width: 3px;
	border-top-style: double;
	border-top-color: $shop-border-color;
}
