{% load i18n %}

<table style="width: 100%; background-color: #fff; border-collapse: collapse; margin-bottom: 20px;">
	<caption style="font-weight: bold; font-size: 130%; padding: 10px 15px; text-align: center; border-bottom: 2px solid #eee;">
		{% trans "Your Details" %}
	</caption>
	<tr>
		<td style="text-align: right; padding: 10px 15px; border-bottom: 2px solid #eee;">{% trans "Email" %}:</td>
		<td style="text-align: left; padding: 10px 15px; border-bottom: 2px solid #eee;">{{ customer.email }}</td>
	</tr>
	<tr>
		<td style="text-align: right; padding: 10px 15px; border-bottom: 2px solid #eee; vertical-align: top;">{% trans "Billing Address" %}:</td>
		<td style="text-align: left; padding: 10px 15px; border-bottom: 2px solid #eee;">
			<pre style="margin: 0;">{{ order.billing_address_text }}</pre>
		</td>
	</tr>
	<tr>
		<td style="text-align: right; padding: 10px 15px; border-bottom: 2px solid #eee; vertical-align: top;">{% trans "Shipping Address" %}:</td>
		<td style="text-align: left; padding: 10px 15px; border-bottom: 2px solid #eee;">
			<pre style="margin: 0;">{{ order.shipping_address_text }}</pre>
		</td>
	</tr>
</table>
