.customer-first_name, .customer-last_name {
	width: 50%;
	display: inline-block;
}

.customer-first_name {
	padding-right: 0.5rem;

	.djng-form-control-feedback {
		padding-right: 1rem;
	}
}

.customer-last_name {
	padding-left: 0.5rem;
}
