{% extends "./authenticated-base.html" %}
{% load i18n %}

{% block form-title %}{% trans "Change Password" %}{% endblock %}

{% block form-content %}
<form name="{{ form_name }}" djng-endpoint="{% url 'shop:password-change' %}" role="form" novalidate>
	{% include "./form-messages.html" %}
	{% include "./change-password-fields.html" %}
</form>
{% endblock form-content %}
