{% load static sekizai_tags sass_tags %}{% spaceless %}

{% include "shop/djng-form.html" %}

{% block extra-styles %}{% endblock %}

{% block extra-scripts %}
	{% addtoblock "js" %}<script src="{% static 'shop/js/utils.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% endblock %}

{% block dialog_form %}{% verbatim %}
<div class="alert alert-danger">Please extend template <code>shop/checkout/dialog-base.html</code> and override <code>{% block dialog_form %}</code></div>
{% endverbatim %}{% endblock %}

{% endspaceless %}
