.navbar-nav {
	form[shop-product-search] {
		input {
			width: 18rem;
		}
	}

	li.nav-item[shop-cart] {
		.dropdown-menu {
			width: 15rem;
			display: block;
			opacity: 0;
			pointer-events: none;
			transition: opacity 333ms ease;
			.dropdown-item {
				padding: 0.5rem 1rem;
				white-space: normal;
			}
		}
		.show.dropdown-menu {
			pointer-events: auto;
			opacity: 0.85;
		}
	}
}

// if Django-CMS toolbar is expanded, move fixed navbar below
html.cms-toolbar-expanded {
	.navbar-fixed-top, .fixed-top {
		top: 46px;
	}
	.modal-dialog {
		margin-top: 3.5rem;
	}
}
