{% extends "shop/email/base.html" %}
{% load i18n %}

{% block email-title %}Request a Password Reset{% endblock %}

{% block email-body %}
<p>You're receiving this e-mail because you or someone else has requested a password reset
for your user account '{{ user }}' at {{ site_name }}. It can be safely ignored if you did not
request a password reset.</p>
<p>Please <a href="{{ protocol }}://{{ domain }}{{ password_reset_confirm_url }}{{ uid }}/{{ token }}">
reset your password here</a>.</p>
<p>Sincerely,<br/>{{ site_name }}</p>
{% endblock email-body %}
