{% load static cascade_tags sekizai_tags sass_tags %}{% spaceless %}

{% addtoblock "js" %}<script src="{% static 'djng/js/django-angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "djng.forms" %}

<djng-forms-set endpoint="{% url 'shop:checkout-upload' %}">
	{% for child in instance.child_plugin_instances %}{% render_plugin child %}{% endfor %}
</djng-forms-set>

{% endspaceless %}
