{% load i18n %}{% spaceless %}
{# This template is shared between Django and AngularJS #}
<figure class="figure">
	<a {% if ng %}ng-href="{% templatetag openvariable %}product.product_url{% templatetag closevariable %}"{% else %}href="{{ product.product_url }}"{% endif %}>
		<h5{% if ng %} ng-bind="product.product_name"{% endif %}>{{ product.product_name }}</h5>
		<div{% if ng %} ng-bind-html="product.media"{% endif %}>{{ product.media }}</div>
	</a>
	<figcaption class="figure-caption mt-2">
	{% block figcaption %}
		<div class="lead">{% trans "Price" %}: <strong{% if ng %} ng-bind="product.price"{% endif %}>{{ product.price }}</strong></div>
		<div{% if ng %} ng-bind-html="product.caption"{% endif %}>{{ product.caption|safe }}</div>
	{% endblock figcaption %}
	</figcaption>
</figure>
{% endspaceless %}
