{% load i18n static menu_tags sekizai_tags %}

{% addtoblock "js" %}<script src="{% static 'djng/js/django-angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "djng.forms" %}

{% spaceless %}
<div class="container">
	<nav aria-label="breadcrumb" class="my-3">
		<ol class="breadcrumb">
			{% show_breadcrumb 0 "bootstrap4/menu/breadcrumb.html" %}
			<li class="ml-auto d-none d-sm-inline-block">
				{% trans "Found Products" %}: <span class="badge badge-primary" djng-bind-if="catalog.count">{{ paginator.count }}</span>
			</li>
		</ol>
	</nav>
</div>
{% endspaceless %}
