{% extends "shop/email/base.html" %}
{% load i18n %}

{% block email-title %}Register User{% endblock %}

{% block email-body %}
<p>You're receiving this e-mail because you or someone else has requested an auto-generated password
for your newly created user account '{{ user }}' at {{ site_name }}. It can be safely ignored if
you did not create this account.</p>
<p>In the future, please use username {{ email }} with password {{ password }} to sign
into {{ absolute_base_uri }}.</p>
<p>Sincerely,<br/>{{ site_name }}</p>
{% endblock email-body %}
