# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-02-25 19:51
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0008_notification_recipient'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Email',
        ),
    ]
