{% extends "./anonymous-base.html" %}
{% load i18n %}

{% block form-title %}{% trans "Proceed as guest" %}{% endblock %}

{% block form-content %}
<form name="{{ form_name }}" djng-endpoint="{% url 'shop:continue-as-guest' %}" role="form" novalidate>
	<input type="hidden" name="dummy" ng-model="dummy" />
	<div class="form-group">
		<button type="button" ng-click="{% include "./proceed-with.html" %}" class="btn btn-primary">
			{% trans "Continue as guest" %}&emsp;<i class="fa fa-sign-in"></i>
		</button>
	</div>
</form>
{% endblock form-content %}
