@import "bootstrap/scss/functions";
@import "bootstrap/scss/variables";
@import "bootstrap/scss/mixins/breakpoints";

.shop-catalog-list {
	@include media-breakpoint-only(md) {
		.shop-list-item:nth-child(n+15):nth-last-child(1) {
			display: none;
		}
	}
	@include media-breakpoint-only(xl) {
		.shop-list-item:nth-child(n+15):nth-last-child(1) {
			display: none;
		}
	}
}
