{% extends "./anonymous-base.html" %}
{% load i18n %}

{% block form-title %}{% trans "Password Forgotten?" %}{% endblock %}

{% block form-content %}
<form name="{{ form_name }}" djng-endpoint="{% url 'shop:password-reset-request' %}" role="form" novalidate>
	{% include "./password-reset-request-fields.html" %}
</form>
{% endblock %}
